---
name: Bug report
about: Create a report to help us improve rapids-singlecell
title: "[BUG]"
type: Bug
assignees: ''

---

**Describe the bug**
A clear and concise description of what the bug is.

**Steps/Code to reproduce bug**
Follow this guide http://matthewrocklin.com/blog/work/2018/02/28/minimal-bug-reports to craft a minimal bug report. This helps us reproduce the issue you're having and resolve the issue more quickly.

**Expected behavior**
A clear and concise description of what you expected to happen.

**Environment details (please complete the following information):**
 - Environment location: [Bare-metal, Docker, Cloud(specify cloud provider)]
 - Linux Distro/Architecture: [Ubuntu 22.04 amd64]
 - GPU Model/Driver: [A100 and driver 470.161.03]
 - CUDA: [11.4]
 - Method of Rapids install: [conda, pip or from source]
   - If method of install is [conda], run `conda list` and include results here
   - If method of install is [pip], run `pip list` and include results here
   - If method of install is [from source], provide versions of `cmake` & `gcc/g++` and commit hash of build

**Additional context**
Add any other context about the problem here.
